/* maker options.
MAKER_ADD_DEPENDENCY="file.h"
MAKER_ADD_DEPENDENCY="makeutilities.h"
MAKER_ADD_DEPENDENCY="optionreader.h"
*/

/************ file.h **************
$Revision: 1.2 $
$Author: pb $
$Date: 2001/05/09 14:52:14 $
***********************************/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "optionreader.h"
#include "file.h"

/**
   This is the main class for maker. It runs short commands on
   File, OptionReader and MakeUtilities.
   @version 1.0
   @author Philip Bergen (pb@instadia.net)
*/
class Maker
{
public:

  /**
     Constructs the object and adds all files it can get from
     the OptionReader.
     @param opt The OptionReader. Must not be NULL!
  */
  Maker(OptionReader *opt)
  {
    options=opt;

    mainFile=new File(options->getMainfile());
    File::addFile(mainFile);
    addHeaderFiles();
  }

  /**
     Does nothing.
   */
  ~Maker()
  {
  }

  /**
     Resolves all dependencies and tags files for rebuild.
  */
  void resolveDependencies(void)
  {
    mainFile->resolveDependencies();
    mainFile->tagRebuild();    
  }

  /**
     Generates the make script.
     @return True if successful.
  */
  bool generateMakescript(void)
  {
    FILE *fout=fopen(options->getMakescript(),"w+");
    if (fout)
      {
	mainFile->writeCompilation(fout,options->getCompiler());
	if (options->performLink())
	  {
	    mainFile->writeLink(fout,options->getExecutable(),
				options->getLinker(),
				options->getLinkerTail());
	  }
	fclose(fout);
      }
    else
      {
	return false;
      }
    return true;
  }

  /**
     Generates the dot files. 
     @return True if successful.
  */
  bool generateDotOutput(void)
  {
    if (options->getDotoutput())
      {
	return mainFile->writeDot(options->getDotoutput());
      }
    return true;
  }

private:
  /**
     Adds header files to fileRoot.
     @see OptionReader::getOptionFileIndex
  */
  void addHeaderFiles(void)
  {
    File *tmpFile;
    char **argv;
    int argc=options->getArguments(argv);
    for (int i=1;i<argc;i++)
      {
	if (argv[i][0]!='-' && i!=options->getOptionFileIndex())
	  {
	    tmpFile=new File(argv[i]);
	    if (tmpFile->getFileName() && tmpFile->getExtension()==EXTH)
	      {
		File::addFile(tmpFile);
	      }
	    else
	      {
		delete tmpFile;
	      }
	  }
      }
  }

  OptionReader *options;
  File *mainFile;
};

/*************** LOG *****************
 $Log: maker.h,v $
 Revision 1.2  2001/05/09 14:52:14  pb
 Added NOLINK option.

 Revision 1.1  2001/05/09 12:10:56  pb
 Cleaned up the source. Added new directive MAKER_ADD_DEPENDENCY.
 Added documentation.

*************************************/
