/******** makeutilities.h **********
$Revision $
$Author: pb $
$Date: 2001/05/08 14:21:28 $
***********************************/
#ifndef _MAKEUTILITIES_H_
#define _MAKEUTILITIES_H_

#include <stdio.h>
#include <string.h>

/**
   Contains only static methods for string manipulation.
   @author Philip Bergen
   @version 1.0
*/
class MakeUtilities
{
 public:
  /**
     Does nothing.
  */
  MakeUtilities()
    {
    }

  /**
     Does nothing.
  */
  ~MakeUtilities()
    {
    }

  /**
     Searches backwards from the end of the string after the first
     occurence of c.
     @param buf Any string.
     @param c Any character.
     @return NULL if there was no instance of c in buf, else a pointer to
     a 'c' in buf.
  */
  static char *strchrReverse(const char *buf,char c)
    {
      if (!buf || !*buf)
	{
	  return NULL;
	}
      char *p=(char *)buf+strlen(buf);
      while (*p!=c && p>=buf)
	{
	  p--;
	}
      if (p<buf)
	{
	  return NULL;
	}
      return p;
    }
  
  /**
     Allocates a copy of buf with new. Caller must delete [] it!
     @param buf	Any string.
     @param extraBytes Amount of extra bytes to allocate.
     @return A pointer to acopy or NULL if buf is NULL.
  */
  static char *getStrCopy(const char *buf, int extraBytes=0)
    {
      if (!buf)
	{
	  return NULL;
	}
      char *p=new char[1+strlen(buf)+extraBytes];
      strcpy(p,buf);
      return p;
    }

  /**
     Changes the extension of a filename.
     @param fileName Any filename with or without the dot.
     @param ext Any extension without the dot.
     @return A string with an extension-altered filename and path.
     CALLER MUST DELETE!
  */
  static char *changeExtension(const char *fileName, const char *ext)
    {
      char *newName=MakeUtilities::getStrCopy(fileName,strlen(ext)+1);
      char *p=MakeUtilities::strchrReverse(newName,'.');
      if (!p)
	{
	  p=newName+strlen(newName)+1;
	  *p='.';
	}
      p[1]=0;
      strcat(newName,ext);
      return newName;
    }
};

#endif
/********************************************
$Log: makeutilities.h,v $
Revision 1.3  2001/05/08 14:21:28  pb
Works 100% and lots of new features.

Revision 1.2  2001/04/28 14:35:10  pb
Added dot-output.

Revision 1.1  2001/04/28 10:11:19  pb
A -perhaps- working version.
********************************************/
